certifi: Python package for providing Mozilla's CA Bundle
=========================================================

Description
-----------

Python package for providing Mozilla's CA Bundle.

License
-------

ISC


Upstream Contact
----------------

Home page: https://pypi.python.org/pypi/certifi

Dependencies
------------

Python, Setuptools
